==> kernel-a-rule-7.0.3-sources.jar: cn/stylefeng/roses/kernel/rule/util/DatabaseTypeUtil.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.rule.util;

import cn.hutool.core.util.StrUtil;
import cn.stylefeng.roses.kernel.rule.enums.DbTypeEnum;

/**
 * 判断数据库类型的工具
 *
 * @author fengshuonan
 * @date 2021/3/27 21:24
 */
public class DatabaseTypeUtil {

    /**
     * 判断数据库类型
     *
     * @author fengshuonan
     * @date 2021/3/27 21:25
     */
    public static DbTypeEnum getDbType(String jdbcUrl) {
        if (StrUtil.isEmpty(jdbcUrl)) {
            return DbTypeEnum.MYSQL;
        }

        if (jdbcUrl.contains(DbTypeEnum.ORACLE.getName())) {
            return DbTypeEnum.ORACLE;
        } else if (jdbcUrl.contains(DbTypeEnum.PG_SQL.getName())) {
            return DbTypeEnum.PG_SQL;
        } else if (jdbcUrl.contains(DbTypeEnum.MS_SQL.getName())) {
            return DbTypeEnum.MS_SQL;
        } else {
            return DbTypeEnum.MYSQL;
        }
    }

}

==> kernel-a-rule-7.3.1-sources.jar: cn/stylefeng/roses/kernel/rule/util/DatabaseTypeUtil.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.rule.util;

import cn.hutool.core.util.StrUtil;
import cn.stylefeng.roses.kernel.rule.enums.DbTypeEnum;

/**
 * 判断数据库类型的工具
 *
 * @author fengshuonan
 * @date 2021/3/27 21:24
 */
public class DatabaseTypeUtil {

    /**
     * 判断数据库类型
     *
     * @author fengshuonan
     * @date 2021/3/27 21:25
     */
    public static DbTypeEnum getDbType(String jdbcUrl) {
        if (StrUtil.isEmpty(jdbcUrl)) {
            return DbTypeEnum.MYSQL;
        }

        // url字符串中包含了dbTypeEnum的name，则判定为该类型
        for (DbTypeEnum dbTypeEnum : DbTypeEnum.values()) {
            if (jdbcUrl.contains(dbTypeEnum.getUrlWords())) {
                return dbTypeEnum;
            }
        }

        return DbTypeEnum.MYSQL;
    }

}
